@@ -2,9 +2,8 @@
 #define _DRV_MEI_CPE_LINUX_H
 /******************************************************************************
 
-                               Copyright (c) 2011
+                              Copyright (c) 2014
                             Lantiq Deutschland GmbH
-                     Am Campeon 3; 85579 Neubiberg, Germany
 
   For licensing information, see the file 'LICENSE' in the root folder of
   this software module.
@@ -33,18 +32,30 @@
 
 #include <linux/sched.h>
 #include <linux/interrupt.h>
+#include <linux/version.h>
 
-#include <asm/ifx/irq.h>
+#if (LINUX_VERSION_CODE < KERNEL_VERSION(3,10,0))
+   #include <asm/ifx/irq.h>
+#else
+   #include <irq.h>
+   #include <net/net_namespace.h>
+   #include <linux/platform_device.h>
+   #include <linux/of_irq.h>
+   #include <linux/of_address.h>
+#endif
 
 #if (MEI_DRV_IFXOS_ENABLE == 0)
 
-#include <linux/version.h>
 #include <linux/wait.h>
 #include <linux/fs.h>
 #include <linux/poll.h>
 #include <linux/types.h>
 
-#include <asm/ifx/ifx_types.h>
+#if (LINUX_VERSION_CODE < KERNEL_VERSION(3,10,0))
+   #include <asm/ifx/ifx_types.h>
+#else
+   #include <ifx_types.h>
+#endif
 
 #endif /* #if (MEI_DRV_IFXOS_ENABLE == 0)*/
 
@@ -78,12 +89,17 @@ typedef irqreturn_t (*usedIsrHandler_t)(int, void *);
    #define KSEG1   (0xa0000000)
 #endif
 
-/* PCI device shared IRQ*/
-#define MEI_DRVOS_SLAVE_IRQ_NUM   INT_NUM_IM4_IRL30
+#if (LINUX_VERSION_CODE < KERNEL_VERSION(2,6,0))
+#define MEI_DRVOS_SIGNAL_PENDING             0
+#else
+#define MEI_DRVOS_SIGNAL_PENDING             signal_pending(current)
+#endif
 
-#define MEI_DRVOS_IRQ_FLAGS_GET(irq_num)   irq_num == MEI_DRVOS_SLAVE_IRQ_NUM ?  \
-                                              IRQF_SHARED | IRQF_TRIGGER_FALLING : \
-                                              IRQ_LEVEL
+#if (LINUX_VERSION_CODE < KERNEL_VERSION(3,10,0))
+#   ifndef PDE_DATA
+#     define PDE_DATA(inode) PDE(inode)->data
+#  endif
+#endif
 
 /**
    Function typedef for the Linux request_irq()
@@ -561,7 +577,7 @@ IFX_time_t MEI_DRVOS_ElapsedTimeMSecGet(
 #define MEI_DRVOS_CRLF                              "\n\r"
 
    /** Kernel - Error Print on Appl-Level (formated) */
-#define MEI_DRVOS_ERR_PRINT_USR(fmt, args...)       printk(KERN_DEBUG fmt "\r", ##args)
+#define MEI_DRVOS_ERR_PRINT_USR(fmt, args...)       printk(fmt "\r", ##args)
 #define MEI_DRVOS_PRINT_INT_RAW(fmt, args...)       printk(fmt, ##args)
 
 #define MEI_PRINT_USR                     MEI_DRVOS_ERR_PRINT_USR
