@@ -1,8 +1,7 @@
 /******************************************************************************
 
-                               Copyright (c) 2011
+                              Copyright (c) 2014
                             Lantiq Deutschland GmbH
-                     Am Campeon 3; 85579 Neubiberg, Germany
 
   For licensing information, see the file 'LICENSE' in the root folder of
   this software module.
@@ -10,7 +9,7 @@
 ******************************************************************************/
 
 /* ============================================================================
-   Description : VINAX Driver, VxWorks BSP part
+   Description : VRX Driver, VxWorks BSP part
    ========================================================================= */
 
 /* ============================= */
@@ -18,7 +17,7 @@
 /* ============================= */
 
 
-#if defined(VXWORKS) && defined(INCLUDE_VINAX)
+#if defined(VXWORKS) && defined(INCLUDE_VRX)
 /*
   sorry for this style, but this is a easy way to include the driver code
   into the board support package of VxWorks
@@ -28,9 +27,9 @@
 #include "drv_mei_cpe_config.h"
 
 #include "ifx_types.h"
-/* add VINAX OS Layer */
+/* add VRX OS Layer */
 #include "drv_mei_cpe_os.h"
-/* add VINAX debug/printout part */
+/* add VRX debug/printout part */
 #include "drv_mei_cpe_dbg.h"
 
 #include "drv_mei_cpe_api.h"
